@@ -3,8 +3,7 @@
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
+    the Free Software Foundation, version 3 of the License.
 
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -15,19 +14,21 @@
     along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
-#[cfg(not(target_os = "linux"))]
-use cli_clipboard::ClipboardProvider;
-#[cfg(target_os = "linux")]
-use clipboard::ClipboardProvider;
+use std::sync::{Arc, Mutex};
+
+use arboard::Clipboard;
 use cursive::{
     event::Key,
     views::{Checkbox, Dialog, EditView, OnEventView, RadioButton, TextView},
     Cursive,
 };
+use lazy_static::lazy_static;
 use pass::Result;
 use ripasso::{crypto::CryptoImpl, pass};
-#[cfg(target_os = "linux")]
-use wl_clipboard_rs::copy::{MimeType, Options, Source};
+
+lazy_static! {
+    static ref CLIPBOARD: Arc<Mutex<Clipboard>> = Arc::new(Mutex::new(Clipboard::new().unwrap()));
+}
 
 /// Displays an error in a cursive dialog
 pub fn errorbox(ui: &mut Cursive, err: &pass::Error) {
@@ -50,32 +51,12 @@ pub fn errorbox(ui: &mut Cursive, err: &pass::Error) {
     ui.add_layer(ev);
 }
 
-#[cfg(target_os = "linux")]
 /// Copies content to the clipboard.
-/// It first tries to copy to a wayland clipboard, and if that's not availible due to that the
-/// user runs x11/mac/windows we instead try the more generic clipboard crate.
-pub fn set_clipboard(content: String) -> Result<()> {
-    let opts = Options::new();
-    let result = opts.copy(
-        Source::Bytes(content.clone().into_bytes().into()),
-        MimeType::Autodetect,
-    );
-    if result.is_err() {
-        let mut ctx = clipboard::ClipboardContext::new()?;
-        ctx.set_contents(content)?;
-    }
-    Ok(())
+pub fn set_clipboard(content: &String) -> Result<()> {
+    Ok(CLIPBOARD.lock().unwrap().set_text(content)?)
 }
 
-#[cfg(not(target_os = "linux"))]
-/// Copies content to the clipboard. With the more generic clipboard crate.
-pub fn set_clipboard(content: String) -> Result<()> {
-    let mut ctx = cli_clipboard::ClipboardContext::new()?;
-    ctx.set_contents(content)?;
-    Ok(())
-}
-
-pub fn get_value_from_input(s: &mut Cursive, input_name: &str) -> Option<std::rc::Rc<String>> {
+pub fn get_value_from_input(s: &mut Cursive, input_name: &str) -> Option<std::sync::Arc<String>> {
     let mut password = None;
     s.call_on_name(input_name, |e: &mut EditView| {
         password = Some(e.get_content());
